multi_mode_animated_snack library

A Flutter library for displaying customizable, animated snack bars.

Classes

AnimatedSnackBar
Core class for displaying animated snack bars.
AnimatedWrapperInterface
Wrapper interface for animated widgets.
BaseSnackBarConfig
Abstract base class
OverlayWrapper
A wrapper widget that provides an Overlay for displaying snack bars.
SlideYJumpWrapper
This class implements the AnimatedWrapperInterface and provides a method to animate widgets with a slide effect in the Y direction and a jump effect.
SlideYWrapper
This class implements the AnimatedWrapperInterface and provides a method to animate widgets with a slide effect in the Y direction.

Enums

AnimateConfig
Configuration for the animation effect of the snack bar.
AppearanceMode
Defines the position where the snack bar will appear on the screen.
ConfigMode
Predefined configuration modes for customizing the snack bar appearance.